==> v0.0.15.tar.gz: community/src/gonganxitong/user.go <==
package gonganxitong

import (
	"net/http"
	"time"

	"shylinux.com/x/ice"
	"shylinux.com/x/icebergs/base/aaa"
	"shylinux.com/x/icebergs/base/mdb"
	"shylinux.com/x/icebergs/base/nfs"
	"shylinux.com/x/icebergs/base/web"
	kit "shylinux.com/x/toolkits"

	"shylinux.com/x/community/src/gonganxitong/model"
)

type user struct {
	Table
	setting    setting
	template   string `data:"4b-Z_r8dZmm1pHdd2h4A10VVYX4OIHvemlLjsHKBj2s"`
	create     string `name:"create open_id* avatar usernick"`
	modify     string `name:"modify info" role:"void"`
	list       string `name:"list uid auto" role:"void"`
	email      string `name:"email email*"`
	setCookie  string `name:"setCookie" help:"切换" role:"void"`
	sendCookie string `name:"sendCookie" help:"授权" role:"void"`
}

func (s user) Create(m *ice.Message, arg ...string) {
	m.OptionDefault(aaa.AVATAR, m.Option(ice.MSG_AVATAR), aaa.USERNICK, m.Option(ice.MSG_USERNICK))
	if msg := s.Table.Select(m.Spawn(), m.OptionSimple(model.OPEN_ID)...); msg.Length() == 0 {
		s.Insert(m, kit.Simple(m.OptionSimple(model.OPEN_ID, model.AVATAR), model.NAME, m.Option(aaa.USERNICK))...)
		m.Option(model.USER_UID, m.Result())
	} else {
		s.Update(m, kit.Dict(m.OptionSimple(model.AVATAR), model.NAME, m.Option(aaa.USERNICK)), msg.AppendSimple(model.UID)...)
		m.Option(model.USER_UID, msg.Append(model.UID))
	}
}
func (s user) Modify(m *ice.Message, arg ...string) {
	s.Update(m, kit.Dict(m.OptionSimple(model.INFO)), model.UID, m.Option(model.USER_UID))
}
func (s user) Remove(m *ice.Message, arg ...string) {
	s.Delete(m, m.OptionSimple(model.UID)...)
}
func (s user) SelectTotal(m *ice.Message, arg ...string) string {
	msg := m.Spawn()
	s.Fields(msg, "count(*) AS total")
	return s.Select(msg, arg...).Append("total")
}
func (s user) List(m *ice.Message, arg ...string) {
	if len(arg) == 0 {
		if m.IsTech() {
			s.Limit(m, 100)
			s.Select(m, arg...).Table(func(value ice.Maps) {
				if value[model.UID] != m.Option(model.USER_UID) {
					m.PushButton(s.SetCookie)
				} else {
					m.PushButton()
				}
			})
			m.EchoQRCode(m.MergePodCmd("", m.PrefixKey()+"/action/sendCookie", ice.FROM_DAEMON, m.Option(ice.MSG_DAEMON))).Echo("<br/>").Echo("请扫码授权")
			m.StatusTimeCount(mdb.TOTAL, s.SelectTotal(m))
		}
	} else {
		s.SelectDetail(m, model.UID, arg[0])
		if m.Append(model.AUTH_UID) == "" && arg[0] == m.Option(model.USER_UID) {
			m.EchoInfoButton("请申请个人认证", s.AuthCreate)
		}
	}
}
func (s user) AuthCreate(m *ice.Message, arg ...string) {
	m.Options(s.Select(m.Spawn(), model.UID, m.Option(model.USER_UID)).AppendSimple(model.NAME, model.INFO))
	s.Table.AuthCreate(m, 2, m.Option(model.AUTH_UID))
}
func (s user) SendTemplate(m *ice.Message, arg ...string) { // from uid url type name hash
	msg := s.Select(m, model.UID, kit.Select(m.Option(model.USER_UID), arg, 1))
	m.Cmdy("web.chat.wx.template", "", m.Config(nfs.TEMPLATE), msg.Append(model.OPEN_ID), kit.Select("", arg, 2),
		"thing7", kit.Select("", arg, 3), "thing12", kit.Select("", arg, 4), "character_string2", kit.Cut(kit.Select("", arg, 5), 6),
		"time11", time.Now().Format("2006年01月02日 15:04"), "thing18", kit.Select(kit.Select(m.Option(ice.MSG_USERNAME), m.Option(ice.MSG_USERNICK)), arg, 0),
	)
}
func (s user) SendCookie(m *ice.Message, arg ...string) {
	if m.Option(ice.MSG_METHOD) == http.MethodGet {
		m.EchoInfoButton("请确认授权", s.SendCookie)
	} else {
		m.Cmd(web.SPACE, m.Option(ice.FROM_DAEMON), "cookie", m.Option(model.USER_UID), model.USER_UID)
	}
}
func (s user) SetCookie(m *ice.Message, arg ...string) {
	m.ProcessCookie(model.USER_UID, m.Option(model.UID))
}
func (s user) Email(m *ice.Message, arg ...string) {
	s.Table.Update(m, kit.Dict(m.OptionSimple(model.EMAIL)))
}

func init() { ice.TeamCtxCmd(user{}) }

==> v0.0.19.tar.gz: community/src/gonganxitong/user.go <==
package gonganxitong

import (
	"net/http"
	"time"

	"shylinux.com/x/ice"
	"shylinux.com/x/icebergs/base/aaa"
	"shylinux.com/x/icebergs/base/mdb"
	"shylinux.com/x/icebergs/base/nfs"
	"shylinux.com/x/icebergs/base/web"
	kit "shylinux.com/x/toolkits"

	"shylinux.com/x/community/src/gonganxitong/model"
)

type user struct {
	Table
	setting    setting
	template   string `data:"4b-Z_r8dZmm1pHdd2h4A10VVYX4OIHvemlLjsHKBj2s"`
	create     string `name:"create open_id* avatar usernick"`
	modify     string `name:"modify info" role:"void"`
	list       string `name:"list uid auto" role:"void"`
	email      string `name:"email email*"`
	setCookie  string `name:"setCookie" help:"切换" role:"void"`
	sendCookie string `name:"sendCookie" help:"授权" role:"void"`
}

func (s user) Create(m *ice.Message, arg ...string) {
	m.OptionDefault(aaa.AVATAR, m.Option(ice.MSG_AVATAR), aaa.USERNICK, m.Option(ice.MSG_USERNICK))
	if msg := s.Table.Select(m.Spawn(), m.OptionSimple(model.OPEN_ID)...); msg.Length() == 0 {
		s.Insert(m, kit.Simple(m.OptionSimple(model.OPEN_ID, model.AVATAR), model.NAME, m.Option(aaa.USERNICK))...)
		m.Option(model.USER_UID, m.Result())
	} else {
		s.Update(m, kit.Dict(m.OptionSimple(model.AVATAR), model.NAME, m.Option(aaa.USERNICK)), msg.AppendSimple(model.UID)...)
		m.Option(model.USER_UID, msg.Append(model.UID))
	}
}
func (s user) Modify(m *ice.Message, arg ...string) {
	s.Update(m, kit.Dict(m.OptionSimple(model.INFO)), model.UID, m.Option(model.USER_UID))
}
func (s user) Remove(m *ice.Message, arg ...string) {
	s.Delete(m, m.OptionSimple(model.UID)...)
}
func (s user) List(m *ice.Message, arg ...string) {
	if len(arg) == 0 {
		if m.IsTech() {
			s.Limit(m, 300)
			s.Select(m, arg...).Table(func(value ice.Maps) {
				if value[model.UID] != m.Option(model.USER_UID) {
					m.PushButton(s.SetCookie)
				} else {
					m.PushButton()
				}
			})
			m.EchoQRCode(m.MergePodCmd("", m.PrefixKey()+"/action/sendCookie", ice.FROM_DAEMON, m.Option(ice.MSG_DAEMON))).Echo("<br/>").Echo("请扫码授权")
			m.StatusTimeCount(mdb.TOTAL, s.SelectTotal(m))
		}
	} else {
		s.SelectDetail(m, model.UID, arg[0])
		if m.Append(model.AUTH_UID) == "" && arg[0] == m.Option(model.USER_UID) {
			m.EchoInfoButton("请申请个人认证", s.AuthCreate)
		}
	}
}
func (s user) SelectTotal(m *ice.Message, arg ...string) string {
	msg := m.Spawn()
	s.Fields(msg, "count(*) AS total")
	return s.Select(msg, arg...).Append(model.TOTAL)
}
func (s user) Email(m *ice.Message, arg ...string) {
	s.Table.Update(m, kit.Dict(m.OptionSimple(model.EMAIL)))
}
func (s user) AuthCreate(m *ice.Message, arg ...string) {
	msg := s.Select(m.Spawn(), model.UID, m.Option(model.USER_UID))
	if msg.Length() == 0 {
		s.Insert(m.Spawn(), model.UID, m.Option(model.USER_UID), model.NAME, m.Option(ice.MSG_USERNAME))
		m.Options(model.NAME, m.Option(ice.MSG_USERNAME))
	} else {
		m.Options(msg.AppendSimple(model.NAME, model.INFO))
	}
	s.Table.AuthCreate(m, 2, m.Option(model.AUTH_UID))
}
func (s user) SendCookie(m *ice.Message, arg ...string) {
	if m.Option(ice.MSG_METHOD) == http.MethodGet {
		m.EchoInfoButton("请确认授权", s.SendCookie)
	} else {
		m.Cmd(web.SPACE, m.Option(ice.FROM_DAEMON), "cookie", m.Option(model.USER_UID), model.USER_UID)
	}
}
func (s user) SetCookie(m *ice.Message, arg ...string) {
	m.ProcessCookie(model.USER_UID, m.Option(model.UID))
}
func (s user) SendTemplate(m *ice.Message, arg ...string) { // from uid url type name hash
	msg := s.Select(m, model.UID, kit.Select(m.Option(model.USER_UID), arg, 1))
	m.Cmdy("web.chat.wx.template", "", m.Config(nfs.TEMPLATE), msg.Append(model.OPEN_ID), kit.Select("", arg, 2),
		"thing7", kit.Select("", arg, 3), "thing12", kit.Select("", arg, 4), "character_string2", kit.Cut(kit.Select("", arg, 5), 6),
		"time11", time.Now().Format("2006年01月02日 15:04"), "thing18", kit.Select(kit.Select(m.Option(ice.MSG_USERNAME), m.Option(ice.MSG_USERNICK)), arg, 0),
	)
}

func init() { ice.TeamCtxCmd(user{}) }
